@@ -418,5 +418,5 @@ class CodeStyleChecker:
 
     @staticmethod
     def save_text_in_file(file_path, text):
-        with open(file_path, 'w') as file:
+        with open(file_path, 'w', encoding="utf-8") as file:
             file.write(text)
